==> google_applovin_unity_ads-2.3.30.tar.gz: android/src/main/java/com/btcpiyush/ads/google_applovin_unity_ads/FlutterAppLovinNativeAd.java <==
// Copyright 2022 Bitcoding
// See the License for the specific language governing permissions and
// limitations under the License.

package com.btcpiyush.ads.google_applovin_unity_ads;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import com.applovin.mediation.MaxError;
import com.applovin.mediation.nativeAds.MaxNativeAdListener;
import com.applovin.mediation.nativeAds.MaxNativeAdLoader;
import com.applovin.mediation.nativeAds.MaxNativeAdView;
import com.applovin.sdk.AppLovinSdk;
import com.btcpiyush.ads.google_applovin_unity_ads.GoogleApplovinUnityAdsPlugin.NativeAdFactory;
import com.google.android.gms.ads.LoadAdError;
import com.google.android.gms.ads.nativead.NativeAd;

import io.flutter.plugin.platform.PlatformView;

/**
 * A wrapper for {@link NativeAd}.
 */
class FlutterAppLovinNativeAd extends FlutterAd {
    private static final String TAG = "FlutterNativeAd";

    @NonNull
    private final AdInstanceManager manager;
    @NonNull
    private final String adUnitId;
    @NonNull
    private final NativeAdFactory adFactory;
    @NonNull
    private final AppLovinSdk _appLovinSdk;

/*
    @NonNull
    final GoogleApplovinUnityAdsPlugin.GeoedgeSdkFactory geoSdkFactory;
*/

    @NonNull
    private final Boolean isMediumAds;
    @NonNull
    private final FlutterAdLoader flutterAdLoader;
    @Nullable
    private MaxNativeAdLoader nativeAdLoader;
    private MaxNativeAdView _nativeAdView;

    static class Builder {
        @Nullable
        private AdInstanceManager manager;
        @Nullable
        private String adUnitId;
        @Nullable
        private NativeAdFactory adFactory;
        @NonNull
        private Boolean isMediumAds;
        @Nullable
        private Integer id;
        @Nullable
        private FlutterAdLoader flutterAdLoader;
        @Nullable
        private AppLovinSdk _appLovinSdk;

/*        @Nullable
        private GoogleApplovinUnityAdsPlugin.GeoedgeSdkFactory geoSdkFactory;*/

        public Builder setAdFactory(@NonNull NativeAdFactory adFactory) {
            this.adFactory = adFactory;
            return this;
        }

        public Builder setId(int id) {
            this.id = id;
            return this;
        }

        public Builder setManager(@NonNull AdInstanceManager manager) {
            this.manager = manager;
            return this;
        }

        public Builder setAdUnitId(@NonNull String adUnitId) {
            this.adUnitId = adUnitId;
            return this;
        }


        public Builder IsMediumNativeAds(@NonNull Boolean isMediumAds) {
            this.isMediumAds = isMediumAds;
            return this;
        }

        public Builder setFlutterAdLoader(@NonNull FlutterAdLoader flutterAdLoader) {
            this.flutterAdLoader = flutterAdLoader;
            return this;
        }

        public Builder setAppLovinSdk(@NonNull AppLovinSdk _appLovinSdk) {
            this._appLovinSdk = _appLovinSdk;
            return this;
        }

        FlutterAppLovinNativeAd build() {
            if (manager == null) {
                throw new IllegalStateException("AdInstanceManager cannot be null.");
            } else if (adUnitId == null) {
                throw new IllegalStateException("AdUnitId cannot be null.");
            } else if (adFactory == null) {
                throw new IllegalStateException("NativeAdFactory cannot be null.");
            } else if (_appLovinSdk == null) {
                throw new IllegalStateException("AppLovinSdk cannot be null.");
            }

            if (isMediumAds == null)
                isMediumAds = false;

            final FlutterAppLovinNativeAd nativeAd =
                    new FlutterAppLovinNativeAd(
                            id,
                            manager,
                            adUnitId,
                            isMediumAds,
                            adFactory,
                            flutterAdLoader,
                            _appLovinSdk);
            return nativeAd;
        }
    }

    protected FlutterAppLovinNativeAd(
            int adId,
            @NonNull AdInstanceManager manager,
            @NonNull String adUnitId,
            @NonNull Boolean isMediumAds,
            @NonNull NativeAdFactory adFactory,
            @NonNull FlutterAdLoader flutterAdLoader,
            @NonNull AppLovinSdk _appLovinSdk) {
        super(adId);
        this.manager = manager;
        this.adUnitId = adUnitId;
        this.isMediumAds = isMediumAds;
        this.adFactory = adFactory;
        this.flutterAdLoader = flutterAdLoader;
        this._appLovinSdk = _appLovinSdk;
    }

    @Override
    void load() {
        final MaxNativeAdListener loadedListener = new FlutterAppLovinNativeAdLoadedListener(this, adUnitId);
        _nativeAdView =  isMediumAds ? adFactory.createAppLovinMediumNativeAd(manager.getActivity()) : adFactory.createAppLovinNativeAd(manager.getActivity());
        flutterAdLoader.loadAppLovinNativeAd( manager.getActivity(),
                adUnitId, _appLovinSdk, loadedListener, _nativeAdView);
    }

    void onNativeAdLoaded() {
        manager.onAdLoaded(adId, null);
    }

    void onNativeAdFailedToLoad(MaxError error) {
        manager.onAdFailedToLoad(adId, new FlutterAd.FlutterLoadAdError(new LoadAdError(error.getCode(), error.getMessage(), error.getMediatedNetworkErrorMessage(),null, null)));
    }

    void onNativeAdClicked() {
        manager.onAdClicked(adId);
    }

    @Override
    @Nullable
    public PlatformView getPlatformView() {
        if (_nativeAdView == null) {
            return null;
        }

        return new FlutterPlatformView(_nativeAdView);
    }

    @Override
    void dispose() {
        if (nativeAdLoader != null) {
            nativeAdLoader.destroy();
            nativeAdLoader = null;
        }
    }
}

==> google_applovin_unity_ads-2.3.31.tar.gz: android/src/main/java/com/btcpiyush/ads/google_applovin_unity_ads/FlutterAppLovinNativeAd.java <==
// Copyright 2022 Bitcoding
// See the License for the specific language governing permissions and
// limitations under the License.

package com.btcpiyush.ads.google_applovin_unity_ads;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import com.applovin.mediation.MaxError;
import com.applovin.mediation.nativeAds.MaxNativeAdListener;
import com.applovin.mediation.nativeAds.MaxNativeAdLoader;
import com.applovin.mediation.nativeAds.MaxNativeAdView;
import com.applovin.sdk.AppLovinSdk;
import com.btcpiyush.ads.google_applovin_unity_ads.GoogleApplovinUnityAdsPlugin.NativeAdFactory;
import com.google.android.gms.ads.LoadAdError;
import com.google.android.gms.ads.nativead.NativeAd;

import java.util.Map;

import io.flutter.plugin.platform.PlatformView;

/**
 * A wrapper for {@link NativeAd}.
 */
class FlutterAppLovinNativeAd extends FlutterAd {
    private static final String TAG = "FlutterNativeAd";

    @NonNull
    private final AdInstanceManager manager;
    @NonNull
    private final String adUnitId;
    @Nullable
    private Map<String, Object> customOptions;
    @NonNull
    private final NativeAdFactory adFactory;
    @NonNull
    private final AppLovinSdk _appLovinSdk;

/*
    @NonNull
    final GoogleApplovinUnityAdsPlugin.GeoedgeSdkFactory geoSdkFactory;
*/

    @NonNull
    private final Boolean isMediumAds;
    @NonNull
    private final FlutterAdLoader flutterAdLoader;
    @Nullable
    private MaxNativeAdLoader nativeAdLoader;
    private MaxNativeAdView _nativeAdView;

    static class Builder {
        @Nullable
        private AdInstanceManager manager;
        @Nullable
        private String adUnitId;
        @Nullable
        private NativeAdFactory adFactory;
        @NonNull
        private Boolean isMediumAds;
        @Nullable
        private Integer id;
        @Nullable
        private FlutterAdLoader flutterAdLoader;
        @Nullable
        private Map<String, Object> customOptions;
        @Nullable
        private AppLovinSdk _appLovinSdk;

/*        @Nullable
        private GoogleApplovinUnityAdsPlugin.GeoedgeSdkFactory geoSdkFactory;*/

        public Builder setAdFactory(@NonNull NativeAdFactory adFactory) {
            this.adFactory = adFactory;
            return this;
        }

        public Builder setId(int id) {
            this.id = id;
            return this;
        }

        public Builder setManager(@NonNull AdInstanceManager manager) {
            this.manager = manager;
            return this;
        }

        public Builder setAdUnitId(@NonNull String adUnitId) {
            this.adUnitId = adUnitId;
            return this;
        }


        public Builder IsMediumNativeAds(@NonNull Boolean isMediumAds) {
            this.isMediumAds = isMediumAds;
            return this;
        }

        public Builder setCustomOptions(@Nullable Map<String, Object> customOptions) {
            this.customOptions = customOptions;
            return this;
        }

        public Builder setFlutterAdLoader(@NonNull FlutterAdLoader flutterAdLoader) {
            this.flutterAdLoader = flutterAdLoader;
            return this;
        }

        public Builder setAppLovinSdk(@NonNull AppLovinSdk _appLovinSdk) {
            this._appLovinSdk = _appLovinSdk;
            return this;
        }

        FlutterAppLovinNativeAd build() {
            if (manager == null) {
                throw new IllegalStateException("AdInstanceManager cannot be null.");
            } else if (adUnitId == null) {
                throw new IllegalStateException("AdUnitId cannot be null.");
            } else if (adFactory == null) {
                throw new IllegalStateException("NativeAdFactory cannot be null.");
            } else if (_appLovinSdk == null) {
                throw new IllegalStateException("AppLovinSdk cannot be null.");
            }

            if (isMediumAds == null)
                isMediumAds = false;

            final FlutterAppLovinNativeAd nativeAd =
                    new FlutterAppLovinNativeAd(
                            id,
                            manager,
                            adUnitId,
                            isMediumAds,
                            customOptions,
                            adFactory,
                            flutterAdLoader,
                            _appLovinSdk);
            return nativeAd;
        }
    }

    protected FlutterAppLovinNativeAd(
            int adId,
            @NonNull AdInstanceManager manager,
            @NonNull String adUnitId,
            @NonNull Boolean isMediumAds,
            @Nullable Map<String, Object> customOptions,
            @NonNull NativeAdFactory adFactory,
            @NonNull FlutterAdLoader flutterAdLoader,
            @NonNull AppLovinSdk _appLovinSdk) {
        super(adId);
        this.manager = manager;
        this.adUnitId = adUnitId;
        this.isMediumAds = isMediumAds;
        this.customOptions = customOptions;
        this.adFactory = adFactory;
        this.flutterAdLoader = flutterAdLoader;
        this._appLovinSdk = _appLovinSdk;
    }

    @Override
    void load() {
        final MaxNativeAdListener loadedListener = new FlutterAppLovinNativeAdLoadedListener(this, adUnitId);
        _nativeAdView =  isMediumAds ? adFactory.createAppLovinMediumNativeAd(manager.getActivity(), customOptions) : adFactory.createAppLovinNativeAd(manager.getActivity(), customOptions);
        flutterAdLoader.loadAppLovinNativeAd( manager.getActivity(),
                adUnitId, _appLovinSdk, loadedListener, _nativeAdView);
    }

    void onNativeAdLoaded() {
        manager.onAdLoaded(adId, null);
    }

    void onNativeAdFailedToLoad(MaxError error) {
        manager.onAdFailedToLoad(adId, new FlutterAd.FlutterLoadAdError(new LoadAdError(error.getCode(), error.getMessage(), error.getMediatedNetworkErrorMessage(),null, null)));
    }

    void onNativeAdClicked() {
        manager.onAdClicked(adId);
    }

    @Override
    @Nullable
    public PlatformView getPlatformView() {
        if (_nativeAdView == null) {
            return null;
        }

        return new FlutterPlatformView(_nativeAdView);
    }

    @Override
    void dispose() {
        if (nativeAdLoader != null) {
            nativeAdLoader.destroy();
            nativeAdLoader = null;
        }
    }
}
